//	GhostImage.cpp - A faint ghost image class.
//  ----------------------------------------------------------------------------
//	This file is part of 'GameTemplate', template code for a game.
//	Copyright (C) 2011  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#include "GhostImage.h"
#include "NiallsDrawingLib/Drawer.h"
#include "ImageManager.h"
#include "Random.h"
#include "FilePath.h"
#include "PostProc.h"

//------------------------------------------------------------------------------
uint32_t GhostImage::shader = 0;

//------------------------------------------------------------------------------
GhostImage::GhostImage():
image(0)
{
	scale = Random::getGlobal().getRandomFloat();
	speed = 0.001f + (Random::getGlobal().getRandomFloat() * 0.005f);

	position.x = 128.0f + (Random::getGlobal().getRandomFloat() * (1280.0f-256.0f));
	position.y = 128.0f + (Random::getGlobal().getRandomFloat() * (720.0f-256.0f));
}

//------------------------------------------------------------------------------
GhostImage::~GhostImage()
{

}

//------------------------------------------------------------------------------
void GhostImage::draw(Drawer *d, float fade, bool funTimes)
{
	int tempint;
	float size, alpha;

	if(funTimes && !shader)
	{
		FilePath shaderPath(FilePath::getDataFilesDir().getChild("shaders"));

		shader = d->loadShader(shaderPath.getChild("ghostFeather.vert").getPath(),
							   shaderPath.getChild("ghostFeather.frag").getPath());
	}

	if(!image)
	{
		tempint = (int)(Random::getGlobal().getRandomFloat() * (float)(PostProc::featherImages.size() * 0.9999f));

		image = ImageManager::getInstance().getRandomImage();
		featherImage = PostProc::featherImages[tempint];
	}

	scale += speed;
	if(scale >= 1.0f)
	{
		tempint = (int)(Random::getGlobal().getRandomFloat() * (float)(PostProc::featherImages.size() * 0.9999f));

		image = ImageManager::getInstance().getRandomImage();
		featherImage = PostProc::featherImages[tempint];

		speed = 0.001f + (Random::getGlobal().getRandomFloat() * 0.005f);
		position.x = 128.0f + (Random::getGlobal().getRandomFloat() * (1280.0f-256.0f));
		position.y = 128.0f + (Random::getGlobal().getRandomFloat() * (720.0f-256.0f));

		scale -= 1.0f;
	}

	size = 0.5f + (scale * 1.5f);
	if(scale < 0.5f)
		alpha = scale * 2.0f;
	else
		alpha = (1.0f-((scale-0.5f)*2.0f));

	alpha *= 0.1f * fade;

	if(funTimes)
	{
		d->useSecondImage(featherImage);
		d->useShader(shader);
	}

	d->drawImage(image, position.x-(size*256.0f), position.y-(size*256.0f), size, size, 1.0f, 1.0f, 1.0f, alpha);

	if(funTimes)
	{
		d->useShader(0);
		d->useSecondImage(0);
	}
}
