//	GlitchImage.h - A glitching image class.
//  ----------------------------------------------------------------------------
//	This file is part of 'GameTemplate', template code for a game.
//	Copyright (C) 2011  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#ifndef GLITCHIMAGE_H_
#define GLITCHIMAGE_H_

#include "TwoFloats.h"

#include <stdint.h>

class Drawer;

///	A glitching image class.
class GlitchImage
{
  public:
	///	Constructor.
	GlitchImage();
	///	Destructor.
	~GlitchImage();

	///	Draws the glitched image.
	void draw(Drawer *d, bool funTimes);

	///	Sets the image's position.
	void setPosition(const TwoFloats& pos);

	///	Sets the image's distance from the centre.
	void setHide(float val);
  private:
	///	Helper method to randomise the image's sections.
	void randomiseSections();

	///	Used to stagger the loading of new images.
	static int loadingStagger;
	///	The feathering shader.
	static uint32_t featherShader;

	///	The actual image to draw.
	uint32_t image;
	///	The index of the feather image to use.
	int featherIndex;

	///	Where to draw the image.
	TwoFloats position;

	///	As the player performs the rituals, the image will move away from the centre and fade out.
	float hide;

	///	The number of glitched sections we have.
	enum
	{
		NumSections = 8
	};

	///	Used to store the positions of the horizontal glitched sections of the image.
	TwoFloats sections[NumSections];
	///	Used to store the heights of the horizontal glitched sections of the image.
	float sectionHeights[NumSections];

	///	Used to determine when to switch which image to display.
	int newImageCount;
	///	Used to determine when to randomise the sections.
	int sectionCount;
};

#endif
