//	GlitchText.cpp - A glitching text(image-based) class.
//  ----------------------------------------------------------------------------
//	This file is part of 'GameTemplate', template code for a game.
//	Copyright (C) 2011  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#include "GlitchText.h"
#include "NiallsDrawingLib/Drawer.h"
#include "Random.h"

//------------------------------------------------------------------------------
GlitchText::GlitchText(const TwoFloats& pos):
position(pos),
jitterCount(30),
colours(false),
colourCount(15),
fadeIn(0.0f),
fade(8.0f)
{

}

//------------------------------------------------------------------------------
GlitchText::~GlitchText()
{

}

//------------------------------------------------------------------------------
void GlitchText::draw(Drawer *d, uint32_t image)
{
	float alpha;
	TwoFloats pos(position);

	if(fade <= 0.0f)
		return;
	else
		fade -= 0.01f;

	if(fadeIn < 1.0f)
		fadeIn += 0.075f;

	if(fadeIn < 1.0f)
		alpha = fadeIn;
	else if(fade > 1.0f)
		alpha = 1.0f;
	else
		alpha = fade;

	--jitterCount;
	if(jitterCount < 0)
	{
		if(Random::getGlobal().getRandomFloat() > 0.5f)
			jitterPos = 0.0f;
		else
		{
			jitterPos.x = (Random::getGlobal().getRandomFloat() * 16.0f) - 8.0f;
			jitterPos.y = (Random::getGlobal().getRandomFloat() * 16.0f) - 8.0f;
		}

		jitterCount = (int)(Random::getGlobal().getRandomFloat() * 15.0f);
	}

	--colourCount;
	if(colourCount < 0)
	{
		if(Random::getGlobal().getRandomFloat() > 0.5f)
			colours = false;
		else
		{
			colours = true;

			redPos.x = (Random::getGlobal().getRandomFloat() * 16.0f) - 8.0f;
			redPos.y = (Random::getGlobal().getRandomFloat() * 16.0f) - 8.0f;
			greenPos.x = (Random::getGlobal().getRandomFloat() * 16.0f) - 8.0f;
			greenPos.y = (Random::getGlobal().getRandomFloat() * 16.0f) - 8.0f;
			bluePos.x = (Random::getGlobal().getRandomFloat() * 16.0f) - 8.0f;
			bluePos.y = (Random::getGlobal().getRandomFloat() * 16.0f) - 8.0f;
		}

		colourCount = (int)(Random::getGlobal().getRandomFloat() * 30.0f);
	}

	pos = position + jitterPos;

	if(colours)
	{
		d->setBlendMode(Drawer::Additive);

		pos = position + redPos;
		d->drawImage(image, pos.x, pos.y, 1.0f, 1.0f, 1.0f, 0.0f, 0.0f, alpha);
		pos = position + greenPos;
		d->drawImage(image, pos.x, pos.y, 1.0f, 1.0f, 0.0f, 1.0f, 0.0f, alpha);
		pos = position + bluePos;
		d->drawImage(image, pos.x, pos.y, 1.0f, 1.0f, 0.0f, 0.0f, 1.0f, alpha);

		d->setBlendMode(Drawer::AlphaBlend);
	}
	else
		d->drawImage(image, pos.x, pos.y, 1.0f, 1.0f, 0.0f, 0.0f, 0.0f, alpha);
}
