//	GlitchText.h - A glitching text(image-based) class.
//  ----------------------------------------------------------------------------
//	This file is part of 'GameTemplate', template code for a game.
//	Copyright (C) 2011  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#ifndef GLITCHTEXT_H_
#define GLITCHTEXT_H_

#include "TwoFloats.h"

#include <stdint.h>

class Drawer;

///	A glitching text(image-based) class.
class GlitchText
{
  public:
	///	Constructor.
	GlitchText(const TwoFloats& pos);
	///	Destructor.
	~GlitchText();

	///	Draws the text.
	void draw(Drawer *d, uint32_t image);
  private:
	///	The text's position.
	TwoFloats position;

	///	Used to jitter the text about.
	int jitterCount;
	///	Used to jitter the text about.
	TwoFloats jitterPos;

	///	Used to display the text's individual colour channels.
	bool colours;
	///	Used to display the text's individual colour channels.
	int colourCount;
	///	Used to display the text's individual colour channels.
	TwoFloats redPos;
	///	Used to display the text's individual colour channels.
	TwoFloats greenPos;
	///	Used to display the text's individual colour channels.
	TwoFloats bluePos;

	///	Used to fade the text in initially.
	float fadeIn;
	///	Used to fade the text out after a while.
	float fade;
};

#endif
