//	ImageManager.cpp - Singleton responsible for keeping track of all the
//					   images.
//  ----------------------------------------------------------------------------
//	This file is part of 'GameTemplate', template code for a game.
//	Copyright (C) 2011  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#include "ImageManager.h"
#include "NiallsDrawingLib/Drawer.h"
#include "NiallsDrawingLib/ImageLoader.h"
#include "FilePath.h"
#include "Random.h"

#include <cassert>

//------------------------------------------------------------------------------
ImageManager& ImageManager::getInstance()
{
	static ImageManager retval;

	return retval;
}

//------------------------------------------------------------------------------
void ImageManager::loadImages(Drawer *d)
{
	FilePath imagesPath = FilePath::getDataFilesDir().getChild("images");

	assert(imagesPath.getNumChildren() > 0);

	if((int)images.size() < imagesPath.getNumChildren())
	{
		ImageData data;
		ImageLoader loader;

		data = loader.loadImage(imagesPath.getChild(images.size()).getPath());
		images.push_back(d->loadImage(data.data, data.width, data.height));
	}
}

//------------------------------------------------------------------------------
uint32_t ImageManager::getRandomImage() const
{
	int index = (int)(Random::getGlobal().getRandomFloat() * ((float)images.size()-0.01f));

	assert(images.size() > 0);

	return images[index];
}

//------------------------------------------------------------------------------
ImageManager::ImageManager()
{

}

//------------------------------------------------------------------------------
ImageManager::~ImageManager()
{

}
