//	ImageManager.h - Singleton responsible for keeping track of all the images.
//  ----------------------------------------------------------------------------
//	This file is part of 'GameTemplate', template code for a game.
//	Copyright (C) 2011  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#ifndef IMAGEMANAGER_H_
#define IMAGEMANAGER_H_

#include <vector>
#include <stdint.h>

class Drawer;

///	Singleton responsible for keeping track of all the images.
class ImageManager
{
  public:
	///	Returns the sole instance of the ImageManager.
	static ImageManager& getInstance();

	///	Called in GameState::draw() to load in the images one-by-one.
	void loadImages(Drawer *d);

	///	Returns a random image.
	uint32_t getRandomImage() const;
  private:
	///	Constructor.
	ImageManager();
	///	Destructor.
	~ImageManager();

	///	All the images currently loaded.
	std::vector<uint32_t> images;
};

#endif
