//	NoteScreen.cpp - The initial screen.
//  ----------------------------------------------------------------------------
//	This file is part of 'GameTemplate', template code for a game.
//	Copyright (C) 2011  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#include "NoteScreen.h"
#include "NiallsDrawingLib/OpenGLDrawer.h"
#include "NiallsDrawingLib/ImageLoader.h"
#include "Images.h"
#include "PostProc.h"
#include "Random.h"

//------------------------------------------------------------------------------
uint32_t NoteScreen::background = 0;
uint32_t NoteScreen::text = 0;

//------------------------------------------------------------------------------
NoteScreen::NoteScreen(Application *app):
GameState(app),
counter(320),
currentNoise(0),
noiseCount(3),
firstRun(true),
funTimes(false)
{

}

//------------------------------------------------------------------------------
NoteScreen::~NoteScreen()
{

}

//------------------------------------------------------------------------------
void NoteScreen::draw(Drawer *d)
{
	int tempint;

	if(firstRun)
	{
		funTimes = d->canSupport(Drawer::Shaders) && d->canSupport(Drawer::FrameBuffer);
		firstRun = false;
	}

	if(!PostProc::shader)
	{
		ImageData data;
		ImageLoader loader;
		FilePath shaderPath(FilePath::getDataFilesDir().getChild("shaders"));

		data = loader.loadImage(Images::noteback_png, Images::noteback_pngSize);
		background = d->loadImage(data.data, data.width, data.height);

		data = loader.loadImage(Images::note_png, Images::note_pngSize);
		text = d->loadImage(data.data, data.width, data.height);

		data = loader.loadImage(Images::noise1_jpg, Images::noise1_jpgSize);
		PostProc::images[0] = d->loadImage(data.data, data.width, data.height);

		data = loader.loadImage(Images::noise2_jpg, Images::noise2_jpgSize);
		PostProc::images[1] = d->loadImage(data.data, data.width, data.height);

		data = loader.loadImage(Images::noise3_jpg, Images::noise3_jpgSize);
		PostProc::images[2] = d->loadImage(data.data, data.width, data.height);

		data = loader.loadImage(Images::noise4_jpg, Images::noise4_jpgSize);
		PostProc::images[3] = d->loadImage(data.data, data.width, data.height);

		if(funTimes)
		{
			PostProc::shader = d->loadShader(shaderPath.getChild("postProc.vert").getPath(),
											 shaderPath.getChild("postProc.frag").getPath());
		}
	}

	if(funTimes)
		d->startFrameBufferDrawing();

	d->drawImage(background, 0, 0, 0.625f, 0.703125f);
	d->drawImage(background, 1280, 0, -0.625f, 0.703125f);
	d->drawImage(text, 640-512, 360-128);

	//Post-processing.
	if(funTimes)
	{
		d->endFrameBufferDrawing();

		--noiseCount;
		if(noiseCount < 0)
		{
			noiseCount = 5;
			tempint = currentNoise;
			while(tempint == currentNoise)
				tempint = (int)(Random::getGlobal().getRandomFloat() * 3.99f);
			currentNoise = tempint;
		}

		d->useSecondImage(PostProc::images[currentNoise]);
		d->useShader(PostProc::shader);
		d->drawImage(d->getFrameBufferImage(), 0, 0);
		d->useShader(0);
		d->useSecondImage(0);
	}

	--counter;
	if(counter <= 0)
		nextState("GamePlay");
}

//------------------------------------------------------------------------------
void NoteScreen::keyDown(const std::string& action,
						 const SDL_keysym& keyPressed)
{
	nextState("GamePlay");
}
