//	NoteScreen.h - The initial screen.
//  ----------------------------------------------------------------------------
//	This file is part of 'GameTemplate', template code for a game.
//	Copyright (C) 2011  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#ifndef NOTESCREEN_H_
#define NOTESCREEN_H_

#include "GameState.h"

#include <stdint.h>

///	The initial screen.
class NoteScreen : public GameState
{
  public:
	///	Constructor.
	NoteScreen(Application *app);
	///	Destructor.
	~NoteScreen();

	///	Draws the state.
	void draw(Drawer *d);

	///	Called when a key down event is received.
	void keyDown(const std::string& action, const SDL_keysym& keyPressed);

	///	Returns the name of this state.
	const std::string getName() const {return "NoteScreen";};
  private:
	///	The background image.
	static uint32_t background;
	///	The note text.
	static uint32_t text;

	///	Counter to determine when to start the game proper.
	int counter;

	///	Used to switch between noise images.
	int currentNoise;
	///	Used to switch between noise images.
	int noiseCount;

	///	Used to ensure we only call Drawer::canSupport() once.
	bool firstRun;
	///	Whether or not the user's graphics card can support shaders and the framebuffer.
	bool funTimes;
};

#endif
