//	StringModel.h - Simple physically-modelled string class.
//  ----------------------------------------------------------------------------
//	This file is part of 'GameTemplate', template code for a game.
//	Copyright (C) 2011  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#ifndef STRINGMODEL_H_
#define STRINGMODEL_H_

#include "CriticalSection.h"

///	Simple physically-modelled string class.
class StringModel
{
  public:
	///	Constructor.
	StringModel();
	///	Destructor.
	~StringModel();

	///	Returns this string's audio for the current block.
	float getSample();

	///	Used to attach another StringModel to this one.
	void setInputString(StringModel *other);

	///	Used to apply the input value to the StringModel's input.
	void applyInput(float val);

	///	This variable will always contain the string's output at the output point.
	/*!
		Used when connecting StringModels. The value of stringOutput is used as
		an input to the StringModel this one has been attached to.

		It's intended as a read-only variable, but modifying it will do no real
		harm.
	 */
	float stringOutput;
  private:
	///	The length of the string in samples.
	int stringLength;
	///	The input position on the string.
	int inputPos;
	///	The output position on the string.
	int outputPos;

	///	The delay line (forward and back).
	float *delayLine[2];
	///	For the low-pass filter at the bridge wrap-around.
	float bridgeFilter;
	///	How much the string's vibrations will decay by.
	float decay;

	///	The attached input string.
	StringModel *input;
	///	Used to apply arbitrary input to the string.
	float waitingInput;

	///	Used to protect input when it's reset to 0.
	CriticalSection critSec;
};

#endif
