//	MouseCursor.h - Singleton class for drawing a mouse cursor.
//  ----------------------------------------------------------------------------
//	This file is part of 'GameTemplate', a game.
//	Copyright (C) 2010  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#ifndef MOUSECURSOR_H_
#define MOUSECURSOR_H_

#include "Widget.h"

#include <stdint.h>

///	Singleton class for drawing a mouse cursor.
class MouseCursor : public Widget
{
  public:
	///	Returns the sole instance of the MouseCursor object.
	static MouseCursor& getInstance();

	///	Draws the cursor.
	void draw(Drawer *d);

	///	Switches between the pointer (false) and hand (true) cursors.
	void setImage(bool val);

	///	So the object knows where the mouse currently is.
	void mouseMove(float x, float y);
	///	Called when a mouse button is clicked or released.
	void mouseButton(bool val, float x, float y);

#ifdef WIN32
	///	Destructor.
	~MouseCursor();
#endif
  private:
	///	The constructor.
	MouseCursor();
#ifndef WIN32
	///	Destructor.
	~MouseCursor();
#endif

	///	The pointer image.
	uint32_t pointer;
	///	The hand image.
	uint32_t hand;
	///	The closed hand image.
	uint32_t handClosed;

	///	The cursor's current position.
	float xPos;
	///	The cursor's current position.
	float yPos;
	///	Whether the cursor's displaying the pointer or the hand.
	bool image;
	///	Whether the user is holding down the mouse button or not.
	bool mouseIsDown;
};

namespace MouseImages
{
    extern const char*  mousecursor_png;
    const int           mousecursor_pngSize = 2914;

    extern const char*  mousecursorhand_png;
    const int           mousecursorhand_pngSize = 2830;

    extern const char*  mousecursorhandclosed_png;
    const int           mousecursorhandclosed_pngSize = 2700;

};

#endif
