//	Widget.h - Base class for any widgets.
//  ----------------------------------------------------------------------------
//	This file is part of 'GameTemplate', a game.
//	Copyright (C) 2010  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#ifndef WIDGET_H_
#define WIDGET_H_

class Drawer;

///	Base class for any widgets.
class Widget
{
  public:
	///	Constructor.
	Widget();
	///	Destructor.
	virtual ~Widget();

	///	Draws the widget.
	virtual void draw(Drawer *d) = 0;

	///	Called when the mouse moves within this widget's bounds.
	virtual void mouseMove(float x, float y) = 0;
	///	Called when a mouse button is clicked or released.
	virtual void mouseButton(bool val, float x, float y) = 0;
	///	Called when the mouse is outside the widget's bounds.
	virtual void mouseLeave(float x, float y) {};

	///	Sets the position of the widget.
	void setPosition(float x, float y);
	///	Returns the x-axis position of the widget.
	float getXPos() const {return xPos;};
	///	Returns the y-axis position of the widget.
	float getYPos() const {return yPos;};

	///	Sets the size of the widget.
	void setSize(float w, float h);
	///	Returns the width of the widget.
	float getWidth() const {return width;};
	///	Returns the height of the widget.
	float getHeight() const {return height;};

	///	Called for mouse moves - does hit-testing and calls the relevant virtual method.
	void mouseMoveTest(float x, float y);
	///	Called for mouse buttons - does hit-testing and calls the relevant virtual method.
	void mouseButtonTest(bool val, float x, float y);
  private:
	///	The widget's x-axis position.
	float xPos;
	///	The widget's y-axis position.
	float yPos;
	///	The widget's width.
	float width;
	///	The widget's height.
	float height;

	///	If the previous mouse down occurred within this widget.
	bool lastMouseDown;
};

#endif
